@@ -3,9 +3,9 @@ Main Engine class - public API for the streaming SQL engine.
 """
 
 from typing import Any
-from .parser import parse_sql
-from .planner import build_logical_plan
-from .executor import execute_plan
+from .core.parser import parse_sql
+from .core.planner import build_logical_plan
+from .core.executor import execute_plan
 
 
 class Engine:
